@@ -4,12 +4,13 @@
     IEEE Transactions on Evolutionary Computation, 3(2), pp.82-102.
     https://ieeexplore.ieee.org/abstract/document/771163
 
-    Since its source code is not openly available, the performance differences between our code and the original
-    paper are very hard (if not impossible) to analyze. We notice that different people may give a different
-    implementation based on different understandings of its algorithmic operations.
+    Since its source code is not openly available till now, the performance differences between our code and
+    the original paper are very hard (if not impossible) to analyze. We notice that different people may give
+    different implementations based on different understandings of its algorithmic operations, which may
+    explain the following performance differences.
 
-    Unfortunately, till now our code *cannot* perfectly repeat the results reported by the original paper.
-    We expect that a much closer open-source implementation could be given in the future.
+    We expect that a much closer open-source implementation could be given in the future, no matter by ourselves
+    or others.
 """
 import numpy as np
 
@@ -22,70 +23,65 @@ if __name__ == '__main__':
 
     problem = {'fitness_function': rastrigin,
                'ndim_problem': ndim_problem,
-               'lower_boundary': -5.12 * np.ones((ndim_problem,)),
-               'upper_boundary': 5.12 * np.ones((ndim_problem,))}
-    options = {'max_function_evaluations': 5000 * 100,
+               'lower_boundary': -5.12*np.ones((ndim_problem,)),
+               'upper_boundary': 5.12*np.ones((ndim_problem,))}
+    options = {'max_function_evaluations': 5000*100,
                'seed_rng': 0,  # undefined in the original paper
                'sigma': 3.0}
     fep = FEP(problem, options)
     results = fep.optimize()
-    print(results)
     print(results['best_so_far_y'])
-    # 22.88404827530138
+    # 36.358572846518655
     # vs 4.6e-2 (from the original paper)
 
     problem = {'fitness_function': ackley,
                'ndim_problem': ndim_problem,
-               'lower_boundary': -32 * np.ones((ndim_problem,)),
-               'upper_boundary': 32 * np.ones((ndim_problem,))}
-    options = {'max_function_evaluations': 1500 * 100,
+               'lower_boundary': -32*np.ones((ndim_problem,)),
+               'upper_boundary': 32*np.ones((ndim_problem,))}
+    options = {'max_function_evaluations': 1500*100,
                'seed_rng': 0,  # undefined in the original paper
                'sigma': 3.0}
     fep = FEP(problem, options)
     results = fep.optimize()
-    print(results)
     print(results['best_so_far_y'])
-    # 1.9075267778220923
+    # 4.614636065481921
     # vs 1.8e-2 (from the original paper)
 
     problem = {'fitness_function': sphere,
                'ndim_problem': ndim_problem,
                'lower_boundary': -100*np.ones((ndim_problem,)),
                'upper_boundary': 100*np.ones((ndim_problem,))}
-    options = {'max_function_evaluations': 1500 * 100,
+    options = {'max_function_evaluations': 1500*100,
                'seed_rng': 0,  # undefined in the original paper
                'sigma': 3.0}
     fep = FEP(problem, options)
     results = fep.optimize()
-    print(results)
     print(results['best_so_far_y'])
-    # 0.20284227582986794
+    # 0.21750264011392764
     # vs 5.7e-4 (from the original paper)
 
     problem = {'fitness_function': step,
                'ndim_problem': ndim_problem,
-               'lower_boundary': -100 * np.ones((ndim_problem,)),
-               'upper_boundary': 100 * np.ones((ndim_problem,))}
-    options = {'max_function_evaluations': 1500 * 100,
+               'lower_boundary': -100*np.ones((ndim_problem,)),
+               'upper_boundary': 100*np.ones((ndim_problem,))}
+    options = {'max_function_evaluations': 1500*100,
                'seed_rng': 0,  # undefined in the original paper
                'sigma': 3.0}
     fep = FEP(problem, options)
     results = fep.optimize()
-    print(results)
     print(results['best_so_far_y'])
-    # 47.0
+    # 38.0
     # vs 0 (from the original paper)
 
     problem = {'fitness_function': rosenbrock,
                'ndim_problem': ndim_problem,
                'lower_boundary': -30*np.ones((ndim_problem,)),
                'upper_boundary': 30*np.ones((ndim_problem,))}
-    options = {'max_function_evaluations': 20000 * 100,
-               'seed_rng': 0,  # undefined in the original paper
+    options = {'max_function_evaluations': 20000*100,
+               'seed_rng': 1,  # undefined in the original paper
                'sigma': 3.0}
     fep = FEP(problem, options)
     results = fep.optimize()
-    print(results)
     print(results['best_so_far_y'])
-    # 19.653232176391665
+    # 17.962224995187768
     # vs mean 5.06 std 5.87 (from the original paper)
