@@ -4,6 +4,7 @@ from pypop7.optimizers.es.ssaes import SSAES
 from pypop7.optimizers.es.dsaes import DSAES
 from pypop7.optimizers.es.csaes import CSAES
 from pypop7.optimizers.es.saes import SAES
+from pypop7.optimizers.es.opoc2006 import OPOC2006
 from pypop7.optimizers.es.sepcmaes import SEPCMAES
 from pypop7.optimizers.es.maes import MAES
 from pypop7.optimizers.es.fmaes import FMAES
@@ -17,5 +18,5 @@ from pypop7.optimizers.es.mmes import MMES
 
 __all__ = [ES,  # base (abstract) class
            RES, SSAES, DSAES, CSAES, SAES,  # representative ES versions during development
-           MAES, FMAES,  # modern ES versions often with state-of-the-art performance
+           OPOC2006, MAES, FMAES,  # modern ES versions often with state-of-the-art performance
            SEPCMAES, R1ES, RMES, LMCMAES, LMCMA, LMMAES, MMES]  # especially for large-scale black-box optimization
